@@ -163,31 +163,43 @@ scale_handler sc_handler[] = {
 #define nr_sc_handlers (sizeof(sc_handler)/sizeof(scale_handler))
 
 typedef struct {
-  char *name;
-  const guint8 *def;
-  int size, type, page, id;
-  GtkWidget *wdg;
-  GdkPixbuf *pxb;
+  char *name;			// Shorthand name (will be amended)
+  const guint8 *def;		// Pointer to the pixmap definition
+  int size, 			// Size of the pixmap
+      page, 			// Components: Definition page
+      id;			// Temp: Callback id
+  GtkWidget *wdg;		// Temp: The widget created
+  GdkPixbuf *pxb;		// Temp: The pixbuf created
 } toggle_button_def;
 
+
+/*
+ *	IMPORTANT: The definitions should be in the same order as the
+ *	type definitions for connection type and element type!
+ */
+
+// Name        Icon definition    Icon def size
+
 toggle_button_def conn_btn[] = {
-  {"series",   comp_series_def,   sizeof(comp_series_def),   ELC_SERIES},
-  {"parallel", comp_parallel_def, sizeof(comp_parallel_def), ELC_PARALLEL},
-  {"empty",    comp_empty_def,    sizeof(comp_empty_def),    ELC_EMPTY}
+  {"series",   comp_series_def,   sizeof(comp_series_def)},
+  {"parallel", comp_parallel_def, sizeof(comp_parallel_def)},
+  {"empty",    comp_empty_def,    sizeof(comp_empty_def)}
 };
 #define conn_btn_len (sizeof(conn_btn)/sizeof(toggle_button_def)-1)
 
+// Name        Icon definition    Icon def size           page
+
 toggle_button_def type_btn[] = {
-  {"discr_c",     comp_cap_def,   sizeof(comp_cap_def),   ELT_CAP,   0},
-  {"discr_l",     comp_ind_def,   sizeof(comp_ind_def),   ELT_IND,   0},
-  {"discr_parlc", comp_lcpar_def, sizeof(comp_lcpar_def), ELT_PARLC, 0},
-  {"discr_serlc", comp_lcser_def, sizeof(comp_lcser_def), ELT_SERLC, 0},
-  {"ostub",       comp_ostub_def, sizeof(comp_ostub_def), ELT_OSTUB, 1},
-  {"sstub",       comp_sstub_def, sizeof(comp_sstub_def), ELT_SSTUB, 1},
-  {"line",        comp_line_def,  sizeof(comp_line_def),  ELT_LINE,  2},
-  {"xform",       comp_xform_def, sizeof(comp_xform_def), ELT_XFORM, 3},
-  {"zy",          comp_zy_def,    sizeof(comp_zy_def),    ELT_ZY,    4},
-  {"empty",       comp_empty_def, sizeof(comp_empty_def), ELC_EMPTY, 9}
+  {"discr_c",     comp_cap_def,   sizeof(comp_cap_def),   0},
+  {"discr_l",     comp_ind_def,   sizeof(comp_ind_def),   0},
+  {"discr_parlc", comp_lcpar_def, sizeof(comp_lcpar_def), 0},
+  {"discr_serlc", comp_lcser_def, sizeof(comp_lcser_def), 0},
+  {"ostub",       comp_ostub_def, sizeof(comp_ostub_def), 1},
+  {"sstub",       comp_sstub_def, sizeof(comp_sstub_def), 1},
+  {"line",        comp_line_def,  sizeof(comp_line_def),  2},
+  {"xform",       comp_xform_def, sizeof(comp_xform_def), 3},
+  {"zy",          comp_zy_def,    sizeof(comp_zy_def),    4},
+  {"empty",       comp_empty_def, sizeof(comp_empty_def), 9}
 };
 #define type_btn_len (sizeof(type_btn)/sizeof(toggle_button_def)-1)
 
@@ -396,6 +408,15 @@ show_cable_data(int which, int c)
   }
 }
 
+/*
+ *	These routines manage the component selection and connection
+ *	type.
+ */
+
+/*	Load the element callbacks and set the button icon, from the
+ *	table supplied.
+ *	Used for the connection type and element buttons.
+ */
 
 void
 load_element_toggles(toggle_button_def *tbl, int len, GCallback cb)
@@ -420,19 +441,26 @@ load_element_toggles(toggle_button_def *tbl, int len, GCallback cb)
   }
 }
 
+/*	Make the possible elements visible according to the connection
+ *	selected (series/parallel)
+ */
 
 void
-element_conn_sensitive(int eltype)
+element_show_possible(int conntype)
 {
   GtkWidget *w;
-  gboolean sens = eltype != ELT_ZY;
 
-  w = lookup_widget(MainWindow, "comp_series_tbtn");
-  gtk_widget_set_sensitive(w, sens);
-  w = lookup_widget(MainWindow, "comp_parallel_tbtn");
-  gtk_widget_set_sensitive(w, sens);
+  w = lookup_widget(MainWindow, "comp_line_tbtn");
+  g_object_set(G_OBJECT(w), "visible", act_el.conn == ELC_SERIES, NULL);
+  w = lookup_widget(MainWindow, "comp_xform_tbtn");
+  g_object_set(G_OBJECT(w), "visible", act_el.conn == ELC_SERIES, NULL);
 }
 
+/*	Set the buttons from the selected element. Common routine to
+ *	set the connection type and element type buttons.
+ *	Have to disable the callbacks temporarily here!
+ */
+
 void
 set_element_toggles(toggle_button_def *tbl, int len, int val)
 {
@@ -440,35 +468,37 @@ set_element_toggles(toggle_button_def *tbl, int len, int val)
   
   for (c = 0; c < len; c++) {
     g_signal_handler_block(G_OBJECT(tbl[c].wdg), tbl[c].id);
-    gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(tbl[c].wdg),
-			    	val == tbl[c].type);
+    gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(tbl[c].wdg), val == c);
     g_signal_handler_unblock(G_OBJECT(tbl[c].wdg), tbl[c].id);
   }
 }
 
+/*	Set the connection type (series/parallel)
+ */
+
 void
-set_element_conn(int val)
+set_element_conn(int type)
 {
   GtkWidget *w;
   
-  set_element_toggles(conn_btn, conn_btn_len, val);
-  act_el.conn = conn_btn[val].type;
-  
-  w = lookup_widget(MainWindow, "comp_line_tbtn");
-  g_object_set(G_OBJECT(w), "visible", act_el.conn == ELC_SERIES, NULL);
-  w = lookup_widget(MainWindow, "comp_xform_tbtn");
+  act_el.conn = type;  
+  set_element_toggles(conn_btn, conn_btn_len, type);
+  element_show_possible(type);
 }
 
+/*	Set the element type
+ */
+
 void
-set_element_type(int val)
+set_element_type(int type)
 {
   GtkWidget *w = lookup_widget(MainWindow, "comp_notebook");
 
-  set_element_toggles(type_btn, type_btn_len, val);
-  act_el.typ = type_btn[val].type;
-  element_conn_sensitive(val);
-  set_discr_mode(val);
-  gtk_notebook_set_current_page(GTK_NOTEBOOK(w), type_btn[val].page);
+  set_element_toggles(type_btn, type_btn_len, type);
+  act_el.typ = type;
+  element_show_possible(type);
+  set_discr_mode(type);
+  gtk_notebook_set_current_page(GTK_NOTEBOOK(w), type_btn[type].page);
 }
 
 
@@ -497,20 +527,8 @@ set_buttons(int which, int state)
 {
   GtkWidget *w;
 
-  gtk_widget_set_sensitive(sc_handler[which].scale,
-    state == ENTRY_VALID || state == ENTRY_SET);
-
-  w = lookup_widget(MainWindow, "circ_newel_btn");
-  gtk_widget_set_sensitive(w,
-    state == ENTRY_VALID || state == ENTRY_SET);
-
-  w = lookup_widget(MainWindow, "circ_upd_el_btn");
-  gtk_widget_set_sensitive(w, 
-    state == ENTRY_VALID || state == ENTRY_SET);
-
-  w = lookup_widget(MainWindow, "circ_delete_btn");
-  gtk_widget_set_sensitive(w,   
-    state == ENTRY_VALID);
+//  gtk_widget_set_sensitive(sc_handler[which].scale,
+//    state == ENTRY_VALID || state == ENTRY_SET);
 }
 
 
@@ -544,7 +562,7 @@ scale_entry_pair_set_entry(int which, double val)
   gtk_entry_set_text(GTK_ENTRY(sc_handler[which].entry), bff);
   g_signal_handler_unblock(G_OBJECT(entry), id);
 
-  set_buttons(which, ENTRY_SET);
+  enable_circ_buttons(CIRCLIST_ENTRYSET);
 }
 
 
@@ -629,10 +647,10 @@ on_comp_entry_changed(GtkEntry *entry, gpointer user_data)
   val = strtod(p, &pend);
   if (p != pend && val != 0) {			// Then it's a valid entry
     scale_entry_pair_set_scale(which, val);
-    set_buttons(which, ENTRY_VALID);
+    enable_circ_buttons(CIRCLIST_ENTRYVALID);
     *sc_handler[which].valdst = val;
   } else {					// Not a valid entry
-    set_buttons(which, ENTRY_INVALID);
+    enable_circ_buttons(CIRCLIST_ENTRYINVALID);
   }
 }
 
@@ -703,17 +721,19 @@ enable_scale_handlers(void)
 //
 
 void
-on_comp_conn_tbtn_clicked(GtkButton *button, gpointer user_data)             
-{                                                                               
-  set_element_conn(GPOINTER_TO_INT(user_data));                                 
-}                                                                               
-                                                                                
-                                                                                
-void                                                                            
-on_comp_type_tbtn_clicked (GtkButton *button, gpointer user_data)             
-{                                                                               
-  set_element_type(GPOINTER_TO_INT(user_data));                                 
-}                                                                               
+on_comp_conn_tbtn_clicked(GtkButton *button, gpointer user_data)
+{
+  set_element_conn(GPOINTER_TO_INT(user_data));
+  enable_circ_buttons(CIRCLIST_CONNCHANGED);
+}
+
+
+void
+on_comp_type_tbtn_clicked (GtkButton *button, gpointer user_data)
+{
+  set_element_type(GPOINTER_TO_INT(user_data));
+  enable_circ_buttons(CIRCLIST_TYPECHANGED);
+}
 
 
 //---------------------------------------------------------------------
@@ -724,10 +744,12 @@ void
 initialize_MainWindow(void)
 {
   char *ttl = g_strconcat(_(prog_title), " - v", prog_version, NULL);
+  GtkWidget *w = lookup_widget(MainWindow, "z0_cbbox");
+  GtkWidget *w1 = lookup_widget(MainWindow, "circpage_vbox");
 
   load_config();
   remote_create_fifos();
-  
+
   pref.chart_z0 = 50.0;
   load_element_toggles(conn_btn, conn_btn_len, 
   			G_CALLBACK(on_comp_conn_tbtn_clicked));
@@ -739,4 +761,5 @@ initialize_MainWindow(void)
 
   gtk_window_set_title(GTK_WINDOW(MainWindow), ttl);
   g_free(ttl);
+
 }
