@@ -30,7 +30,6 @@
 
 #include "support.h"
 #include "types.h"
-#include "chart.h"
 #include "element.h"
 #include "printer.h"
 #include "global.h"
@@ -38,12 +37,12 @@
 #include "log.h"
 #include "aux.h"
 #include "main.h"
+#include "chart_def.h"
+#include "chart.h"
 
 //	Note that the initial_bg is relative to PACKAGE_DATA_DIR
 #define initial_bg "/pixmaps/linsmith/smithent.png"
 
-#define monotype  "Courier New"
-
 gdouble 	 chartw, charth, z0 = 50.0,
 		 last_lw = 0.1;
 gboolean	 logomode = TRUE,
@@ -66,14 +65,14 @@ struct {
   char *name;
   double factor;
 } zoom_table[] = {
-  {"x0.1", 0.1}, {"x0.2", 0.2}, {"0.5", 0.5},
+  {"x0.1", 0.1}, {"x0.15", 0.15}, {"x0.2", 0.2}, 
+  {"x0.3", 0.3}, {"x0.5", 0.5}, {"x0.7", 0.7},
   {"x1", 1.0},
-  {"x2", 2.0}, {"x5", 5.0}, {"x10", 10.0}
+  {"x1.5", 1.5}, {"x2", 2.0}, {"x3", 3.0}, {"x5", 5.0}, 
+  {"x7",   7.0}, {"x10", 10.0}
 };
-#define ZOOM_MIN	-3
-#define ZOOM_MAX	3
-
-#include "chartdef.inc"
+#define ZOOM_MIN	-6
+#define ZOOM_MAX	6
 
 void
 make_group(GnomeCanvasGroup **grp)
@@ -94,9 +93,11 @@ make_group(GnomeCanvasGroup **grp)
 void
 update_chart_z0(void)
 {
-  GtkWidget *e = lookup_widget(MainWindow, "z0_entry");
-  double z0 = atof(gtk_entry_get_text(GTK_ENTRY(e)));
+  GtkWidget *w = lookup_widget(MainWindow, "z0_cbbox");
+  char *p;
+  double z0 = atof(p = gtk_combo_box_get_active_text(GTK_COMBO_BOX(w)));
 
+  g_free(p);
   if (z0 == 0) {
     ok_dialog(_("Value"), _("Invalid value for Zo"));
     return;
@@ -129,13 +130,48 @@ set_chart_background_bitmap(char *bgf)
   gdk_pixbuf_unref(chart_pxm);
   gnome_canvas_set_scroll_region(chart_canvas,
 		0.0, -charth/2, chartw, charth/2);
-
 }
 
 
 void
-set_chart_background_dynamic(void)
+set_chart_background_vector(void)
 {
+  GnomeCanvasGroup *grp = gnome_canvas_root(chart_canvas);
+  int def;
+
+  if (chart_bg) gtk_object_destroy(GTK_OBJECT(chart_bg));
+
+  gnome_canvas_item_new(grp, 
+	gnome_canvas_ellipse_get_type(),
+	"x1", 0.0,
+	"y1", (double) -pref.vec_bg_radius,
+	"x2", (double)  pref.vec_bg_radius * 2, 
+	"y2", (double)  pref.vec_bg_radius,
+	"fill_color_rgba", pref.vec_background,
+	NULL);
+  for (def = 0; def < nrpldefs; def++) {
+    switch (pldef[def].type) {
+      case 'R':
+        setlinestyle(&grp, 1, pldef[def].bold ? pref.arc_color[RB_ARC] :
+						pref.arc_color[R_ARC]);
+        rg_arc(&grp, pldef[def].val + pldef[def].a_max * I, 
+                     pldef[def].val + pldef[def].a_min * I, 1.0, TRUE);
+        break;
+      case 'X':
+        setlinestyle(&grp, 1, pldef[def].bold ? pref.arc_color[XB_ARC] :
+						pref.arc_color[X_ARC]);
+        x_arc(&grp, pldef[def].a_max + pldef[def].val * I, 
+                    pldef[def].a_min + pldef[def].val * I, 1.0);
+        x_arc(&grp, pldef[def].a_max - pldef[def].val * I,
+		    pldef[def].a_min - pldef[def].val * I, 1.0);
+        break;
+    }
+  }
+  gnome_canvas_set_scroll_region(chart_canvas,
+                 0.0,
+                -pref.vec_bg_radius,
+		 pref.vec_bg_radius * 2,
+		 pref.vec_bg_radius);
 }
 
 
@@ -145,7 +181,7 @@ set_chart_background(void)
   if (pref.use_bitmap)
     set_chart_background_bitmap(pref.chart);
   else
-    set_chart_background_dynamic();
+    set_chart_background_vector();
 }
 
 
@@ -171,8 +207,7 @@ draw_extras(void)
 
   if (pref.show_g1) {
     setlinestyle(&bg_group, 1, pref.g1_color);
-    g_arc(&bg_group, 50 - 0.001*I,
-		     50 + 0.001*I);
+    rg_arc(&bg_group, 50 - 1e5*I, 50 + 1e5*I, pref.chart_z0, FALSE);
   }
 }
 
@@ -208,13 +243,16 @@ chart_initialize(void)
 void
 pos2impedance(complex *c, gdouble x, gdouble y)
 {
-  gdouble tX, tY, M;
+  gdouble tX, tY, M,
+	  radius = pref.use_bitmap ? pref.chartradius : pref.vec_bg_radius,
+          x_offs = pref.use_bitmap ? pref.x_offs : 0,
+          y_offs = pref.use_bitmap ? pref.y_offs : 0;
 
-  tX = (x - pref.x_offs - pref.chartradius) / pref.chartradius;
-  tY = y / pref.chartradius;
+  tX = (x - x_offs - radius) / radius;
+  tY = y / radius;
   M = (pow(1.0 - tX, 2.0) + pow(tY, 2.0));
-  *c = z0 * (1.0 - pow(tX, 2.0) - pow(tY, 2.0)) / M +
-       z0 * 2.0 * tY / M * I;
+  *c = pref.chart_z0 * (1.0 - pow(tX, 2.0) - pow(tY, 2.0)) / M -
+       pref.chart_z0 * 2.0 * tY / M * I;
 }
 
 
@@ -234,47 +272,58 @@ void
 update_cursor_values(int x, int y)
 {
   GtkWidget *w;
-  double m, swr, q, wx, wy;
+  double m, swr, q, wx, wy,
+         radius = pref.use_bitmap ? pref.chartradius : pref.vec_bg_radius,
+         x_offs = pref.use_bitmap ? pref.x_offs : 0,
+         y_offs = pref.use_bitmap ? pref.y_offs : 0;
   complex imp, k;
   char bff[50];
   
   gnome_canvas_window_to_world(chart_canvas, x, y, &wx, &wy);
   
-  m = sqrt(pow(wx - pref.x_offs - pref.chartradius, 2.0) + 
-           pow(wy - pref.y_offs, 2.0));
-  if (m > pref.chartradius) return;
+  m = sqrt(pow(wx - x_offs - radius, 2.0) + 
+           pow(wy - y_offs, 2.0));
+  if (m > radius) return;
   stop_logomode();
   pos2impedance(&imp, wx, wy);
   
   k = reflection_coef(imp, z0);
   if (cabs(k) == 1.0) {
-    swr = 999.0;
+    swr = 9999.9;
   } else {
     swr = -(cabs(k) + 1.0)/(cabs(k) - 1.0);
   }
+  if (swr > 10000.0) 
+    swr = 9999.9;
 
+  // Quality factor
   if (creal(imp) != 0.0) {
     q = cimag(imp) / creal(imp);
   } else {
     q = 999.9;
   }
+  if (q > 1000.0)
+    q = 999.9;
+  else
+    if (q < -1000.0)
+      q = -999.9;
 
   w = lookup_widget(MainWindow, "stat_z_lbl");
   sprintf(bff, "<span font_desc=\"%s\">%8.2lf %+8.2lfj</span>", 
-               monotype, creal(imp), cimag(imp));
+               pref.cursor_font, creal(imp), cimag(imp));
   gtk_label_set_markup(GTK_LABEL(w), bff);
 
   w = lookup_widget(MainWindow, "stat_zpol_lbl");
   sprintf(bff, "<span font_desc=\"%s\">%.2lf &lt;%.2lf&#176;</span>", 
-               monotype, cabs(imp), carg(imp)*57.29578);
+               pref.cursor_font, cabs(imp), carg(imp)*57.29578);
   gtk_label_set_markup(GTK_LABEL(w), bff);
   
   w = lookup_widget(MainWindow, "stat_swr_lbl");
-  sprintf(bff, "<span font_desc=\"%s\">%.2lf</span>", monotype, swr);
+  sprintf(bff, "<span font_desc=\"%s\">%.2lf</span>", pref.cursor_font, swr);
   gtk_label_set_markup(GTK_LABEL(w), bff);
 
   w = lookup_widget(MainWindow, "stat_q_lbl");
-  sprintf(bff, "<span font_desc=\"%s\">%.2lf</span>", monotype, q);
+  sprintf(bff, "<span font_desc=\"%s\">%.2lf</span>", pref.cursor_font, q);
   gtk_label_set_markup(GTK_LABEL(w), bff);
 }
 
@@ -317,6 +366,7 @@ point_event(GnomeCanvasItem *item, GdkEvent *event, gpointer data)
       break;
     case GDK_MOTION_NOTIFY:
       if (dragging && (event->motion.state & GDK_BUTTON1_MASK)) {
+// CHANGE chartradius for vector too
 //          move_rotation_cursor(data, atan2(pref.chartradius - item_x,
 //                                           item_y));
       }
@@ -346,8 +396,8 @@ create_load_point(void)
   pt->group = point_group;
   pt->point = gnome_canvas_item_new(point_group,
 		gnome_canvas_ellipse_get_type(),
-  		"width_pixels", 1,
-  		NULL);
+		"width_pixels", 1,
+		NULL);
   pt->handler = g_signal_connect(GTK_OBJECT(pt->point), "event", 
 				 GTK_SIGNAL_FUNC(point_event), pt);
   set_point_fixed(pt, TRUE);
@@ -400,7 +450,10 @@ create_element_line(void)
 void
 show_point(chart_pt pt)
 {
-  double x, y, s2;
+  double x, y, s2,
+         radius = pref.use_bitmap ? pref.chartradius : pref.vec_bg_radius,
+         x_offs = pref.use_bitmap ? pref.x_offs : 0,
+         y_offs = pref.use_bitmap ? pref.y_offs : 0;
   guint32 color;
   complex k = reflection_coef(pt->value, pref.chart_z0);
   
@@ -418,10 +471,10 @@ show_point(chart_pt pt)
 		    creal(pt->value), cimag(pt->value), s2, color);
 
   gnome_canvas_item_set(pt->point,
-	        "x1",  x * pref.chartradius + pref.x_offs - s2, 
- 	        "y1", -y * pref.chartradius + pref.y_offs + s2,
-        	"x2",  x * pref.chartradius + pref.x_offs + s2, 
-        	"y2", -y * pref.chartradius + pref.y_offs - s2,
+	        "x1",  x * radius + x_offs - s2, 
+ 	        "y1", -y * radius + y_offs + s2,
+        	"x2",  x * radius + x_offs + s2, 
+        	"y2", -y * radius + y_offs - s2,
 	        "fill_color_rgba", color,
 	        "outline_color_rgba", pt->fixed ? 0x000000ff : color,
         	NULL);
@@ -474,10 +527,10 @@ foreach_load(GtkTreeModel *model,
   char bff[30];
     
   gtk_tree_model_get(model, iter,
-                LD_FREQ_VAL, &load.f,
-                LD_REAL_VAL, &load.r,
-                LD_REACT_VAL, &load.x,
-                LD_POINT, &load.pt,
+		LD_FREQ_VAL, &load.f,
+		LD_REAL_VAL, &load.r,
+		LD_REACT_VAL, &load.x,
+		LD_POINT, &load.pt,
 		-1);
 
   set_point(load.pt, load.r + I*load.x, ZPT_LOAD);
@@ -563,8 +616,7 @@ combine_impedance(el_definition *el, double f)
   if (debug & DBG_ELEMENTS)
     fprintf(stderr, "[combined] %f %fj\n", creal(act_imp), cimag(act_imp));
 
-  loglist_set_value(load_nr, 2*el_nr + LOG_OVERHEAD,     el_imp);
-  loglist_set_value(load_nr, 2*el_nr + 1 + LOG_OVERHEAD, act_imp);
+  loglist_set_impedance(load_nr, el_nr, el_imp, act_imp, el->typ);
 }
 
 
@@ -624,32 +676,22 @@ add_line_to_list(el_definition *el, complex prev_imp, double f)
       switch (el->conn) {
         case ELC_SERIES:
           setlinestyle(&ln->group, 1, pref.arc_color[Z_ARC]);
-          if (imp_mode)
-            ln->line = r_arc(&ln->group, imp1, imp2);
-          else
-            ln->line = g_arc(&ln->group, imp1, imp2);
+          ln->line = rg_arc(&ln->group, imp1, imp2, pref.chart_z0, imp_mode);
           if (printchart) {
             print_setlinestyle(pref.prt_arc_size[Z_ARC],
                                pref.prt_arc_color[Z_ARC]);
-            if (imp_mode)
-              ln->line = r_arc(NULL, imp1, imp2);
-            else
-              ln->line = g_arc(NULL, imp1, imp2);
+            ln->line = rg_arc(NULL, imp1, imp2, pref.chart_z0, imp_mode);
           }
           break;
         case ELC_PARALLEL:
           setlinestyle(&ln->group, 1, pref.arc_color[Y_ARC]);
-          if (imp_mode)
-            ln->line = g_arc(&ln->group, reciprocal(imp2), reciprocal(imp1));
-          else
-            ln->line = r_arc(&ln->group, reciprocal(imp2), reciprocal(imp1));
+          ln->line = rg_arc(&ln->group, reciprocal(imp2), reciprocal(imp1),
+		pref.chart_z0, !imp_mode);
           if (printchart) {
             print_setlinestyle(pref.prt_arc_size[Y_ARC],
                                pref.prt_arc_color[Y_ARC]);
-            if (!imp_mode)
-              ln->line = r_arc(NULL, reciprocal(imp2), reciprocal(imp1));
-            else
-              ln->line = g_arc(NULL, reciprocal(imp2), reciprocal(imp1));
+            ln->line = rg_arc(NULL, reciprocal(imp2), reciprocal(imp1),
+		pref.chart_z0, !imp_mode);
           }
           break;
         }
@@ -706,17 +748,23 @@ recalc_each_element(GtkTreeModel *model,
     el = act_el;
   } else {
     gtk_tree_model_get(model, iter,
-  		EL_CONN_VAL,  &el.conn,    EL_TYPE_VAL, &el.typ,
-                EL_VAL_VAL1,  &el.val1,	   EL_VAL_VAL2, &el.val2,
-                EL_Z0_VAL,    &el.z0,      EL_VF_VAL,   &el.vf,
-                EL_USE_LOSS,  &el.useloss,
-                EL_LOSS1_VAL, &el.loss1,   EL_MHZ1_VAL, &el.mhz1,
-                EL_LOSS2_VAL, &el.loss2,   EL_MHZ2_VAL, &el.mhz2,
-                -1);
+  		EL_CONN_VAL,  &el.conn,
+		EL_TYPE_VAL,  &el.typ,
+		EL_VAL_VAL1,  &el.val1,
+		EL_VAL_VAL2,  &el.val2,
+		EL_Z0_VAL,    &el.z0,
+		EL_VF_VAL,    &el.vf,
+		EL_USE_LOSS,  &el.useloss,
+		EL_LOSS1_VAL, &el.loss1,
+		EL_MHZ1_VAL,  &el.mhz1,
+		EL_LOSS2_VAL, &el.loss2,
+		EL_MHZ2_VAL,  &el.mhz2,
+		-1);
   }
   gtk_tree_model_get(model, iter,
-                EL_POINTLIST, &el.ptlst,   EL_LINELIST, &el.lnlst,
-                -1);
+		EL_POINTLIST, &el.ptlst,   
+		EL_LINELIST,  &el.lnlst,
+		-1);
 
   if (debug & DBG_ELEMENTS)
     fprintf(stderr, "[each elem] %d, %d, %f, %f\n",
@@ -732,7 +780,7 @@ recalc_each_element(GtkTreeModel *model,
 
   gtk_list_store_set(GTK_LIST_STORE(model), iter,
 		EL_POINTLIST, el.ptlst,
-		EL_LINELIST, el.lnlst,
+		EL_LINELIST,  el.lnlst,
 		-1);
 
   el_nr++;  
@@ -759,8 +807,7 @@ recalc_each_load(GtkTreeModel *model,
 
   act_imp = load.r + I * load.x;
   imp_mode = TRUE;
-  loglist_set_value(load_nr, 0, load.f);
-  loglist_set_value(load_nr, 1, act_imp);
+  loglist_set_load(load_nr, load.f, act_imp);
 
   if (debug & DBG_LOADS)
     fprintf(stderr, "[each load] At %f:  %f %fj\n", load.f, load.r, load.x);
@@ -820,6 +867,7 @@ recalculate_all_export(void)
   close_printer_chart();
 }
 
+
 //---------------------------------------------------------------------
 //	Chart element generation
 //	arcs are in radians!
@@ -857,8 +905,10 @@ do_arc(GnomeCanvasGroup **grp,
   GnomeCanvasPoints *points;
   int nr, a;
   guint32 color;
-  double px, py, arc, arclen, darc, 
-	 radius = pref.chartradius * rad;
+  double px, py, arc, arclen, darc,
+         x_offs = pref.use_bitmap ? pref.x_offs : 0,
+	 y_offs = pref.use_bitmap ? pref.y_offs : 0,
+	 radius = pref.use_bitmap ? pref.chartradius : pref.vec_bg_radius;
   
   if (!grp) {
     print_do_arc(x, y, arcb, arce, rad);
@@ -875,8 +925,8 @@ do_arc(GnomeCanvasGroup **grp,
 
   points = gnome_canvas_points_new(nr);
   for (a = 0; a < nr; a++) {
-    px =  x * pref.chartradius + radius * cos(arcb + a*darc) + pref.x_offs;
-    py = -y * pref.chartradius - radius * sin(arcb + a*darc) + pref.y_offs;
+    px = radius *( x + rad * cos(arcb + a*darc)) + x_offs;
+    py = radius *(-y - rad * sin(arcb + a*darc)) + y_offs;
 
     if (debug & DBG_MATH)
       fprintf(stderr, "[do_arc] %f %f\n", px, py);
@@ -903,6 +953,9 @@ do_line(GnomeCanvasGroup **grp, double x1, double y1,
 {
   GnomeCanvasItem *item;
   GnomeCanvasPoints *points;
+  double radius = pref.use_bitmap ? pref.chartradius : pref.vec_bg_radius,
+         x_offs = pref.use_bitmap ? pref.x_offs : 0,
+         y_offs = pref.use_bitmap ? pref.y_offs : 0;
 
   if (!grp) {
     print_do_line(x1, y1, x2, y2);
@@ -910,10 +963,10 @@ do_line(GnomeCanvasGroup **grp, double x1, double y1,
   }
 
   points = gnome_canvas_points_new(2);
-  points->coords[0] =  x1 * pref.chartradius + pref.x_offs;
-  points->coords[1] = -y1 * pref.chartradius + pref.y_offs;
-  points->coords[2] =  x2 * pref.chartradius + pref.x_offs;
-  points->coords[3] = -y2 * pref.chartradius + pref.y_offs;
+  points->coords[0] =  x1 * radius + x_offs;
+  points->coords[1] = -y1 * radius + y_offs;
+  points->coords[2] =  x2 * radius + x_offs;
+  points->coords[3] = -y2 * radius + y_offs;
 
   item = gnome_canvas_item_new(*grp,
 		gnome_canvas_line_get_type(),
@@ -941,9 +994,11 @@ do_string(GnomeCanvasGroup **grp, char *lbl, double x, double y,
 
 
 GnomeCanvasItem *
-r_arc(GnomeCanvasGroup **grp, complex zb, complex ze)
+rg_arc(GnomeCanvasGroup **grp,
+       complex zb, complex ze, double z0,
+       gboolean imp_mode)
 {
-  double radius, z0 = pref.chart_z0;
+  double radius;
   complex rcb, rce;
 
   radius = (1.0 - reflection_coef(creal(zb), z0)) / 2.0;
@@ -952,37 +1007,31 @@ r_arc(GnomeCanvasGroup **grp, complex zb, complex ze)
   rcb = rcb - (1 - radius);
   rce = rce - (1 - radius);
   
-  return 
-    do_arc(grp, 2.0 - radius, 0.0, carg(rcb), carg(rce), radius);
+  if (cimag(zb) > cimag(ze)) {
+    if (imp_mode)
+      return do_arc(grp, 2.0 - radius, 0.0, carg(rcb), carg(rce), radius);
+    else
+      return do_arc(grp, radius, 0.0, carg(rcb) + M_PI, carg(rce) + M_PI,
+		radius);
+  } else {
+    if (imp_mode)
+      return do_arc(grp, 2.0 - radius, 0.0, carg(rce), carg(rcb), radius);
+    else
+      return do_arc(grp, radius, 0.0, carg(rce) + M_PI, carg(rcb) + M_PI,
+		radius);
+  }
 }
 
 
 GnomeCanvasItem *
-g_arc(GnomeCanvasGroup **grp, complex zb, complex ze)
+x_arc(GnomeCanvasGroup **grp, complex zb, complex ze, double z0)
 {
-  double radius, z0 = pref.chart_z0;
-  complex rcb, rce;
-
-  radius = (1.0 - reflection_coef(creal(zb), z0)) / 2.0;
-  rcb = reflection_coef(zb, z0);
-  rce = reflection_coef(ze, z0);
-  rcb = rcb - (1 - radius);
-  rce = rce - (1 - radius);
-  
-  return 
-    do_arc(grp, radius, 0.0, carg(rcb) + M_PI, carg(rce) + M_PI, radius);
-}
-
-
-GnomeCanvasItem *
-x_arc(GnomeCanvasGroup **grp, complex zb, complex ze)
-{
-  double radius, z0 = pref.chart_z0;
+  double radius;
   complex rcb, rce;
 
   rcb = reflection_coef(zb, z0);
   rce = reflection_coef(ze, z0);
-  
+
   if (cimag(zb) == 0) {
     return do_line(grp, creal(rcb) + 1, 0.0, creal(rce) + 1, 0.0);
   } else {
@@ -1019,7 +1068,12 @@ k_arc(GnomeCanvasGroup **grp, complex zbeg, complex zend, double z0)
   b_ang = carg(b_rc - (rc1 - rcrad));
   e_ang = carg(e_rc - (rc1 - rcrad));
 
-  return do_arc(grp, 1 + rc1 - rcrad, 0.0, b_ang, e_ang, rcrad);
+  switch (pref.rotation) {
+    case TO_GENERATOR:
+      return do_arc(grp, 1 + rc1 - rcrad, 0.0, b_ang, e_ang, rcrad);
+    case TO_LOAD:
+      return do_arc(grp, 1 + rc1 - rcrad, 0.0, e_ang, b_ang, rcrad);
+  }
 }
 
 
@@ -1087,21 +1141,22 @@ create_printer_chart(void)
         cmin = (pldef[el].val + pldef[el].a_min * I) * pref.chart_z0,
         cmax = (pldef[el].val + pldef[el].a_max * I) * pref.chart_z0;
         setlinestyle(NULL,
-        	     pldef[el].wide ? pref.prt_arc_size[RB_ARC] :
+        	     pldef[el].bold ? pref.prt_arc_size[RB_ARC] :
 				      pref.prt_arc_size[R_ARC],
-                     pldef[el].wide ? pref.prt_arc_color[RB_ARC] :
+                     pldef[el].bold ? pref.prt_arc_color[RB_ARC] :
 				      pref.prt_arc_color[R_ARC]);
-        r_arc(NULL, cmax, cmin);
+        rg_arc(NULL, cmax, cmin, pref.chart_z0, TRUE);
         break;
       case 'X':
         cmin = (pldef[el].a_min + pldef[el].val * I) * pref.chart_z0,
         cmax = (pldef[el].a_max + pldef[el].val * I) * pref.chart_z0;
         setlinestyle(NULL,
-                     pldef[el].wide ? pref.prt_arc_size[XB_ARC] :
+                     pldef[el].bold ? pref.prt_arc_size[XB_ARC] :
 				      pref.prt_arc_size[X_ARC],
-                     pldef[el].wide ? pref.prt_arc_color[XB_ARC] :
+                     pldef[el].bold ? pref.prt_arc_color[XB_ARC] :
                                       pref.prt_arc_color[X_ARC]);
-        x_arc(NULL, cmax, cmin);
+        x_arc(NULL, cmax, cmin, pref.chart_z0);
+        x_arc(NULL, conj(cmax), conj(cmin), pref.chart_z0);
         break;
     }
   }
@@ -1122,13 +1177,12 @@ create_printer_chart(void)
 
   if (pref.show_swr) {
     setlinestyle(NULL, pref.prt_swr_size, pref.prt_swr_color);
-    k_arc(NULL, z0/pref.swr_circle - 0.001*I,
-                z0/pref.swr_circle + 0.001*I, z0);
+    k_arc(NULL, z0/pref.swr_circle - 1e-5*I,
+                z0/pref.swr_circle + 1e-5*I, z0);
   }
   if (pref.show_g1) {
     setlinestyle(NULL, pref.prt_g1_size, pref.prt_g1_color);
-    g_arc(NULL, 50 - 0.001*I,
-                50 + 0.001*I);
+    rg_arc(NULL, 1.0 - 1e-5*I, 1.0 + 1e-5*I, 1.0, TRUE);
   }
 }
 
