@@ -176,16 +176,71 @@ initialize_elementtable(void)
 
 
 void
-element_buttons_sensitive(gboolean yes)
+enable_circ_buttons(int action)
 {
-  GtkWidget *w;
+  GtkWidget *wdel, *wclr, *wup, *wdown, *wupd, *wnew;
+  static int selected = FALSE;
 
-  w = lookup_widget(MainWindow, "circ_delete_btn");
-  gtk_widget_set_sensitive(w, yes);
-  w = lookup_widget(MainWindow, "circ_up_btn");
-  gtk_widget_set_sensitive(w, yes);
-  w = lookup_widget(MainWindow, "circ_down_btn");
-  gtk_widget_set_sensitive(w, yes);
+  wdel = lookup_widget(MainWindow, "circ_delete_btn");
+  wclr = lookup_widget(MainWindow, "circ_clear_btn");
+  wup = lookup_widget(MainWindow, "circ_up_btn");
+  wdown = lookup_widget(MainWindow, "circ_down_btn");
+  wupd = lookup_widget(MainWindow, "circ_upd_el_btn");
+  wnew = lookup_widget(MainWindow, "circ_newel_btn");
+
+  switch (action) {
+    case CIRCLIST_SELECT:
+      gtk_widget_set_sensitive(wdel, TRUE);
+      gtk_widget_set_sensitive(wup, TRUE);
+      gtk_widget_set_sensitive(wdown, TRUE);
+      gtk_widget_set_sensitive(wupd, FALSE);
+      gtk_widget_set_sensitive(wnew, TRUE);
+      selected = TRUE;
+      break;
+
+    case CIRCLIST_UNSELECT:
+      gtk_widget_set_sensitive(wdel, FALSE);   
+      gtk_widget_set_sensitive(wup, FALSE);
+      gtk_widget_set_sensitive(wdown, FALSE);   
+      gtk_widget_set_sensitive(wupd, FALSE);
+      gtk_widget_set_sensitive(wnew, TRUE); 
+      selected = FALSE;
+      break;
+
+    case CIRCLIST_ENTRYSET:
+      gtk_widget_set_sensitive(wupd, TRUE);
+      break;
+
+    case CIRCLIST_ENTRYVALID:
+      if (selected)
+        gtk_widget_set_sensitive(wupd, TRUE);
+      gtk_widget_set_sensitive(wnew, TRUE); 
+      break;
+   
+    case CIRCLIST_ENTRYINVALID:
+      if (selected)
+        gtk_widget_set_sensitive(wupd, FALSE);
+      gtk_widget_set_sensitive(wnew, FALSE); 
+      break;
+
+    case CIRCLIST_CONNCHANGED:
+      if (selected)
+        gtk_widget_set_sensitive(wupd, TRUE);
+      gtk_widget_set_sensitive(wnew, TRUE);  
+      break;
+
+    case CIRCLIST_TYPECHANGED:              
+      if (selected)
+        gtk_widget_set_sensitive(wupd, TRUE);
+      gtk_widget_set_sensitive(wnew, TRUE);  
+      break;
+
+    case CIRCLIST_UPDATED:
+      gtk_widget_set_sensitive(wupd, FALSE);
+      break;                               
+  }
+
+  gtk_widget_set_sensitive(wclr, action != CIRCLIST_EMPTY);
 }
 
 //---------------------------------------------------------------------
@@ -353,7 +408,7 @@ fetch_selected_element(GtkTreeView *treeview, el_definition *el)
         format_elements(line_els, line_els_len, (char *)el);
         break;
     }
-    element_buttons_sensitive(TRUE);
+    enable_circ_buttons(CIRCLIST_SELECT);
     return TRUE;
   } else
     return FALSE;
@@ -490,6 +545,8 @@ element_update(el_definition el)
   gtk_tree_selection_select_iter(sel, &active_el_iter);
   act_el = el;
   recalculate_all();
+
+  enable_circ_buttons(CIRCLIST_UPDATED);
 }
 
 
@@ -528,7 +585,35 @@ active_element_remove(void)
   }
 
   if (gtk_tree_model_iter_n_children(GTK_TREE_MODEL(store), NULL) == 0)
-    element_buttons_sensitive(FALSE);
+    enable_circ_buttons(CIRCLIST_EMPTY);
+    
+  elements_changed = TRUE;
+}
+
+
+void
+circlist_clear(void)
+{
+  GtkTreeModel *model;
+  GtkTreeIter iter;
+  chart_ptlist ptlst;   
+  chart_lnlist lnlst;
+  gboolean more;
+
+  model = gtk_tree_view_get_model(GTK_TREE_VIEW(el_view));
+  more = gtk_tree_model_get_iter_first(model, &iter);
+
+  while (more) {
+    gtk_tree_model_get(model, &iter,
+		EL_POINTLIST, &ptlst, EL_LINELIST, &lnlst,  
+		-1);
+    clear_element_ptlist(&ptlst);
+    clear_element_lnlist(&lnlst);
+
+    more = gtk_tree_model_iter_next(model, &iter);
+  }
+  gtk_list_store_clear(GTK_LIST_STORE(model));
+  enable_circ_buttons(CIRCLIST_UNSELECT);
     
   elements_changed = TRUE;
 }
@@ -629,14 +714,14 @@ save_circuit(char *fn)
       return;
     }
   }
+
   if (!(xmlf = fopen(fn, "w"))) {
     ok_dialog(_("Error"), _("Cannot open destination file"));
     return;
   }
   fprintf(xmlf, "<?xml version=\"1.0\"?>\n");
   fprintf(xmlf, "<circuit>\n");
-  fprintf(xmlf, " <version major=\"%s\" minor=\"%s\" micro=\"%s\" />\n",
-		prog_major, prog_minor, prog_micro);
+  fprintf(xmlf, " <version value=\"%s\" />\n", prog_version);
 
   gtk_tree_model_foreach(store, save_each_element, xmlf);
 
@@ -706,8 +791,16 @@ calc_line_impedance(complex zl, double z0, double len, double f)
   double arg = tan(2 * M_PI * len);
   complex stub;
 
-  stub = zl * (1 + I * z0 / zl * arg) /
-              (1 + I * zl / z0 * arg);
+  switch (pref.rotation) {
+    case TO_GENERATOR:
+      stub = zl * (1 + I * z0 / zl * arg) /
+                  (1 + I * zl / z0 * arg);
+      break;
+    case TO_LOAD:
+      stub = zl * (1 - I * z0 / zl * arg) /  
+                  (1 - I * zl / z0 * arg);
+      break;
+  }
 
   if (debug)
     fprintf(stderr, "[line imp] %f %fj\n", creal(stub), cimag(stub));
