@@ -26,17 +26,24 @@
 
 enum {LD_FREQ, LD_REAL, LD_REACT,
       LD_FREQ_VAL, LD_REAL_VAL, LD_REACT_VAL,
+      LD_NB_RVAL, LD_NB_CVAL, LD_NB_EXT,
       LD_POINT, LD_LOGCOL,
       LD_COLS};
       
+enum {LOADLIST_SELECT, LOADLIST_UPDATED, LOADLIST_EDITED,
+      LOADLIST_REMOVED, LOADLIST_EMPTY};
+      
+enum {LOADMODE_R_JX, LOADMODE_NOISE, LOADMODE_REMOTE};
+      
 void	initialize_loadtable(void);
 void    get_load_selected(GtkTreeView *treeview);
 
-int	load_valid(void);
-void	load_append(void);
-void    load_update(void);
+int	load_valid(load_definition *dest);
+void	load_append(load_definition *tload);
+void    load_update(load_definition *tload);
+void	load_modified(int which);
 int	number_loads(void);
-
+void	loadlist_clear();
 void	active_load_update();
 void	active_load_remove(void);
 
